@@ -49,10 +49,10 @@ class MSData:
             # get extension from file name
             ext = os.path.splitext(fileName)[1]
 
-            if ext.lower() == ".mzxml":
+            if ext.lower() == ".mzml":
                 with mzml.MzML(fileName) as reader:
                     self.extractscan(reader, rtRange=rtRange)
-            elif ext.lower() == ".mzml":
+            elif ext.lower() == ".mzxml":
                 with mzxml.MzXML(fileName) as reader:
                     self.extractscan(reader, rtRange=rtRange)
             else:
